py-configurator
===============

.. image:: https://badge.fury.io/py/py-configurator.svg
   :target: http://badge.fury.io/py/py-configurator

.. image:: https://travis-ci.org/ryankanno/py-configurator.png?branch=master
   :target: https://travis-ci.org/ryankanno/py-configurator

.. image:: https://coveralls.io/repos/ryankanno/py-configurator/badge.png?branch=master
   :target: https://coveralls.io/r/ryankanno/py-configurator?branch=master

Just a tiny configuration library I tend to use a lot.

Docs
----
They will end up somewhere.

License
-------
MIT
